@@ -22,10 +22,7 @@ finallyToFulfilled <- function(onFinally) {
   force(onFinally)
   function(value, .visible) {
     onFinally()
-    if (.visible)
-      value
-    else
-      invisible(value)
+    if (.visible) value else invisible(value)
   }
 }
 
@@ -44,13 +41,19 @@ promiseDomain <- list(
     force(onFinally)
 
     # Verify that if onFinally is non-NULL, onFulfilled and onRejected are NULL
-    if (!is.null(onFinally) && (!is.null(onFulfilled) || !is.null(onRejected))) {
-      stop("A single `then` call cannot combine `onFinally` with `onFulfilled`/`onRejected`")
+    if (
+      !is.null(onFinally) && (!is.null(onFulfilled) || !is.null(onRejected))
+    ) {
+      stop(
+        "A single `then` call cannot combine `onFinally` with `onFulfilled`/`onRejected`"
+      )
     }
 
     domain <- current_promise_domain()
 
-    shouldWrapFinally <- !is.null(onFinally) && !is.null(domain) && !is.null(domain$wrapOnFinally)
+    shouldWrapFinally <- !is.null(onFinally) &&
+      !is.null(domain) &&
+      !is.null(domain$wrapOnFinally)
 
     newOnFinally <- if (shouldWrapFinally) {
       domain$wrapOnFinally(onFinally)
@@ -64,33 +67,39 @@ promiseDomain <- list(
       onRejected <- spliced$onRejected
     }
 
-    shouldWrapFulfilled <- !is.null(onFulfilled) && !is.null(domain) && !shouldWrapFinally
-    shouldWrapRejected <- !is.null(onRejected) && !is.null(domain) && !shouldWrapFinally
+    shouldWrapFulfilled <- !is.null(onFulfilled) &&
+      !is.null(domain) &&
+      !shouldWrapFinally
+    shouldWrapRejected <- !is.null(onRejected) &&
+      !is.null(domain) &&
+      !shouldWrapFinally
 
     results <- list(
-      onFulfilled = if (shouldWrapFulfilled) domain$wrapOnFulfilled(onFulfilled) else onFulfilled,
-      onRejected = if (shouldWrapRejected) domain$wrapOnRejected(onRejected) else onRejected
+      onFulfilled = if (shouldWrapFulfilled)
+        domain$wrapOnFulfilled(onFulfilled) else onFulfilled,
+      onRejected = if (shouldWrapRejected)
+        domain$wrapOnRejected(onRejected) else onRejected
     )
     results <- results[!vapply(results, is.null, logical(1))]
-    if (!is.null(domain)) {
-      # If there's a domain, ensure that before any callback is invoked, we
-      # reenter the domain. This is important for this kind of code:
-      #
-      #     with_promise_domain(domain, {
-      #       async_sleep(0.1) %...>% {
-      #         async_sleep(0.1) %...>% {
-      #           # Without re-entry, this would be outside the domain!
-      #         }
-      #       }
-      #     })
-      results <- lapply(results, wrap_callback_reenter, domain = domain)
-    }
+    # If there's a domain, ensure that before any callback is invoked, we
+    # reenter the domain. This is important for this kind of code:
+    #
+    #     with_promise_domain(domain, {
+    #       async_sleep(0.1) %...>% {
+    #         async_sleep(0.1) %...>% {
+    #           # Without re-entry, this would be outside the domain!
+    #         }
+    #       }
+    #     })
+    #
+    # It's important to reenter even if domain is NULL. In that case, we need to
+    # ensure that the current domain is set to NULL while the callback executes.
+    results <- lapply(results, wrap_callback_reenter, domain = domain)
     results
   },
   onError = function(error) {
     domain <- current_promise_domain()
-    if (is.null(domain))
-      return()
+    if (is.null(domain)) return()
     domain$onError(error)
   }
 )
@@ -100,7 +109,10 @@ wrap_callback_reenter <- function(callback, domain) {
   force(domain)
 
   wrapper <- function(...) {
-    reenter_promise_domain(domain, callback(...))
+    # replace = TRUE because we don't care what the current domain is; we're
+    # (temporarily) putting the world back to the way it was when the callback
+    # was bound to a promise.
+    reenter_promise_domain(domain, callback(...), replace = TRUE)
   }
 
   # There are parts of this package that will inspect formals() to see if
@@ -114,7 +126,10 @@ wrap_with_signature <- function(func, formal_args) {
   stopifnot("..." %in% names(formals(func)))
 
   args <- names(formal_args)
-  recall <- rlang::call2(func, !!!rlang::set_names(lapply(args, as.symbol), args))
+  recall <- rlang::call2(
+    func,
+    !!!rlang::set_names(lapply(args, as.symbol), args)
+  )
 
   rlang::new_function(formal_args, recall)
 }
@@ -158,24 +173,17 @@ current_promise_domain <- function() {
 #' @export
 with_promise_domain <- function(domain, expr, replace = FALSE) {
   oldval <- current_promise_domain()
-  if (replace)
-    globals$domain <- domain
-  else
+  if (replace) globals$domain <- domain else
     globals$domain <- compose_domains(oldval, domain)
   on.exit(globals$domain <- oldval)
 
-  if (!is.null(domain))
-    domain$wrapSync(expr)
-  else
-    force(expr)
+  if (!is.null(domain)) domain$wrapSync(expr) else force(expr)
 }
 
 # Like with_promise_domain, but doesn't include the wrapSync call.
-reenter_promise_domain <- function(domain, expr, replace = FALSE) {
+reenter_promise_domain <- function(domain, expr, replace) {
   oldval <- current_promise_domain()
-  if (replace)
-    globals$domain <- domain
-  else
+  if (replace) globals$domain <- domain else
     globals$domain <- compose_domains(oldval, domain)
   on.exit(globals$domain <- oldval)
 
@@ -220,14 +228,17 @@ new_promise_domain <- function(
   ...,
   wrapOnFinally = NULL
 ) {
-  list2env(list(
-    wrapOnFulfilled = wrapOnFulfilled,
-    wrapOnRejected = wrapOnRejected,
-    wrapOnFinally = wrapOnFinally,
-    wrapSync = wrapSync,
-    onError = onError,
-    ...
-  ), parent = emptyenv())
+  list2env(
+    list(
+      wrapOnFulfilled = wrapOnFulfilled,
+      wrapOnRejected = wrapOnRejected,
+      wrapOnFinally = wrapOnFinally,
+      wrapSync = wrapSync,
+      onError = onError,
+      ...
+    ),
+    parent = emptyenv()
+  )
 }
 
 
