@@ -3,7 +3,9 @@ describe("C++ interface", {
     promise(function(resolve, reject) {
       asyncFib(resolve, reject, 3)
     }) %...>%
-      { expect_identical(., 2) } %>%
+      {
+        expect_identical(., 2)
+      } %>%
       wait_for_it()
   })
 
@@ -17,10 +19,12 @@ describe("C++ interface", {
       }) %...>%
         {
           expect_identical(., 2)
-          promise_resolve(TRUE) %...>% {
-            expect_true(!is.null(current_promise_domain()))
-            expect_identical(cd$counts$onFulfilledCalled, 3L)
-          }
+          expect_identical(cd$counts$onFulfilledCalled, 1L)
+          promise_resolve(TRUE) %...>%
+            {
+              expect_true(!is.null(current_promise_domain()))
+              expect_identical(cd$counts$onFulfilledCalled, 2L)
+            }
         } %>%
         wait_for_it()
     })
