@@ -1,5 +1,3 @@
-context("Promise domains")
-
 source("common.R")
 
 async_true <- function() {
@@ -7,36 +5,41 @@ async_true <- function() {
 }
 
 describe("Promise domains", {
-
   it("are reentered during handlers", {
     cd <- create_counting_domain(trackFinally = TRUE)
     p <- with_promise_domain(cd, {
-      async_true() %...>% {
-        expect_identical(cd$counts$onFulfilledCalled, 1L)
-        expect_identical(cd$counts$onFulfilledActive, 1L)
-        10 # sync result
-      } %...>% {
-        expect_identical(cd$counts$onFulfilledCalled, 2L)
-        expect_identical(cd$counts$onFulfilledActive, 1L)
-        promise_resolve(20) # async result
-      }
+      async_true() %...>%
+        {
+          expect_identical(cd$counts$onFulfilledCalled, 1L)
+          expect_identical(cd$counts$onFulfilledActive, 1L)
+          10 # sync result
+        } %...>%
+        {
+          expect_identical(cd$counts$onFulfilledCalled, 2L)
+          expect_identical(cd$counts$onFulfilledActive, 1L)
+          promise_resolve(20) # async result
+        }
     })
 
     expect_identical(cd$counts$onFulfilledBound, 2L)
 
-    p <- p %...>% {
-      expect_identical(cd$counts$onFulfilledCalled, 2L)
-      expect_identical(cd$counts$onFulfilledActive, 0L)
-    }
+    p <- p %...>%
+      {
+        expect_identical(cd$counts$onFulfilledCalled, 2L)
+        expect_identical(cd$counts$onFulfilledActive, 0L)
+      }
 
     expect_identical(cd$counts$onFulfilledBound, 2L)
     p %>% wait_for_it()
 
     with_promise_domain(cd, {
-      p <- async_true() %>% finally(~{
-        expect_identical(cd$counts$onFinallyCalled, 1L)
-        expect_identical(cd$counts$onFinallyActive, 1L)
-      })
+      p <- async_true() %>%
+        finally(
+          ~ {
+            expect_identical(cd$counts$onFinallyCalled, 1L)
+            expect_identical(cd$counts$onFinallyActive, 1L)
+          }
+        )
       expect_identical(cd$counts$onFinallyBound, 1L)
 
       expect_identical(cd$counts$onFulfilledBound, 2L)
@@ -48,19 +51,21 @@ describe("Promise domains", {
     expect_identical(cd$counts$onFulfilledBound, 2L)
 
     with_promise_domain(cd, {
-      p <- async_true() %...>% {
-        expect_identical(., TRUE)
-        expect_identical(cd$counts$onFulfilledCalled, 3L)
-        ten <- 10
-        # This tests if promise domain membership infects subscriptions made
-        # in handlers.
-        promise_resolve(invisible(ten)) %...>% (function(value, .visible) {
-          expect_identical(value, 10)
-          expect_false(.visible)
-          expect_true(!is.null(current_promise_domain()))
-          expect_identical(cd$counts$onFulfilledCalled, 4L)
-        })
-      }
+      p <- async_true() %...>%
+        {
+          expect_identical(., TRUE)
+          expect_identical(cd$counts$onFulfilledCalled, 3L)
+          ten <- 10
+          # This tests if promise domain membership infects subscriptions made
+          # in handlers.
+          promise_resolve(invisible(ten)) %...>%
+            (function(value, .visible) {
+              expect_identical(value, 10)
+              expect_false(.visible)
+              expect_true(!is.null(current_promise_domain()))
+              expect_identical(cd$counts$onFulfilledCalled, 4L)
+            })
+        }
     })
 
     expect_true(is.null(current_promise_domain()))
@@ -74,10 +79,12 @@ describe("Promise domains", {
 
     with_promise_domain(cd1, {
       p1 <- async_true() %>%
-        finally(~{
-          expect_identical(cd1$counts$onFulfilledActive, 1L)
-          expect_identical(cd1$counts$onRejectedActive, 0L)
-        })
+        finally(
+          ~ {
+            expect_identical(cd1$counts$onFulfilledActive, 1L)
+            expect_identical(cd1$counts$onRejectedActive, 0L)
+          }
+        )
       expect_identical(cd1$counts$onFulfilledBound, 1L)
       expect_identical(cd1$counts$onRejectedBound, 1L)
       p1 %>% wait_for_it()
@@ -89,10 +96,12 @@ describe("Promise domains", {
 
     p2 <- with_promise_domain(cd2, {
       promise_reject("a problem") %>%
-        finally(~{
-          expect_identical(cd2$counts$onFulfilledActive, 0L)
-          expect_identical(cd2$counts$onRejectedActive, 1L)
-        })
+        finally(
+          ~ {
+            expect_identical(cd2$counts$onFulfilledActive, 0L)
+            expect_identical(cd2$counts$onRejectedActive, 1L)
+          }
+        )
     }) %>%
       squelch_unhandled_promise_error()
 
@@ -108,11 +117,13 @@ describe("Promise domains", {
 
     with_promise_domain(cd1, {
       p1 <- async_true() %>%
-        finally(~{
-          expect_identical(cd1$counts$onFinallyActive, 1L)
-          expect_identical(cd1$counts$onFulfilledActive, 0L)
-          expect_identical(cd1$counts$onRejectedActive, 0L)
-        })
+        finally(
+          ~ {
+            expect_identical(cd1$counts$onFinallyActive, 1L)
+            expect_identical(cd1$counts$onFulfilledActive, 0L)
+            expect_identical(cd1$counts$onRejectedActive, 0L)
+          }
+        )
       expect_identical(cd1$counts$onFinallyBound, 1L)
       expect_identical(cd1$counts$onFulfilledBound, 0L)
       expect_identical(cd1$counts$onRejectedBound, 0L)
@@ -126,12 +137,15 @@ describe("Promise domains", {
 
     p2 <- with_promise_domain(cd2, {
       promise_reject(TRUE) %>%
-        finally(~{
-          expect_identical(cd2$counts$onFinallyActive, 1L)
-          expect_identical(cd2$counts$onFulfilledActive, 0L)
-          expect_identical(cd2$counts$onRejectedActive, 0L)
-        })
-    }) %>% squelch_unhandled_promise_error()
+        finally(
+          ~ {
+            expect_identical(cd2$counts$onFinallyActive, 1L)
+            expect_identical(cd2$counts$onFulfilledActive, 0L)
+            expect_identical(cd2$counts$onRejectedActive, 0L)
+          }
+        )
+    }) %>%
+      squelch_unhandled_promise_error()
 
     expect_identical(cd2$counts$onFinallyBound, 1L)
     expect_identical(cd2$counts$onFulfilledBound, 0L)
@@ -151,7 +165,9 @@ describe("Promise domains", {
     cd <- create_counting_domain()
     with_promise_domain(cd, {
       promise_resolve(as.symbol("foo")) %...>%
-        { expect_identical(., as.symbol("foo")) } %>%
+        {
+          expect_identical(., as.symbol("foo"))
+        } %>%
         wait_for_it()
     })
   })
@@ -162,12 +178,15 @@ describe("Promise domains", {
     x <- NULL
     with_promise_domain(cd, {
       promise_resolve(NULL) %...>%
-        { x <<- 1L } %...>%
-        { x <<- x + 1L } %>%
+        {
+          x <<- 1L
+        } %...>%
+        {
+          x <<- x + 1L
+        } %>%
         wait_for_it()
     })
     expect_identical(x, 2L)
-
   })
 
   it("doesn't grow the call stack", {
@@ -178,14 +197,18 @@ describe("Promise domains", {
       if (n == 0) {
         return(0)
       } else {
-        promise_resolve(TRUE) %...>% {
-          current_callstack_depth <- length(sys.calls())
-          if (!is.null(.last_callstack_depth)) {
-            expect_identical(current_callstack_depth, .last_callstack_depth)
-          }
+        promise_resolve(TRUE) %...>%
+          {
+            current_callstack_depth <- length(sys.calls())
+            if (!is.null(.last_callstack_depth)) {
+              expect_identical(current_callstack_depth, .last_callstack_depth)
+            }
 
-          recursive_promise(n - 1, .last_callstack_depth = current_callstack_depth)
-        }
+            recursive_promise(
+              n - 1,
+              .last_callstack_depth = current_callstack_depth
+            )
+          }
       }
     }
 
@@ -211,6 +234,5 @@ describe("Promise domains", {
         } %>%
         wait_for_it()
     })
-
   })
 })
